@@ -708,7 +708,7 @@ class TestUnit(unittest.TestCase):
     def test_slice_to_ascending_slice_a(self) -> None:
         self.assertEqual(slice_to_ascending_slice(
                 slice(5, 2, -1), 6),
-                slice(3, 6, 1),
+                slice(3, 6, None),
                 )
 
     def test_slice_to_ascending_slice_b(self) -> None:
